local Recount2 = Recount2
local SM = LibStub:GetLibrary("LibSharedMedia-3.0")
local Recount2_Widgets = Recount2.Widgets

local function SetFontSize(string, size)
	local Font, Height, Flags = string:GetFont()
	string:SetFont(Font, size, Flags)
end









local function Window_MouseDown(self, arg1)
	if arg1=="RightButton" then
		local x, y = GetCursorPosition()
		local scale = self:GetEffectiveScale() 
		y = self:GetTop() - y/scale

		if y<self.titleHeight and self.rightClickTitleFunc then
			self.rightClickTitleFunc(self.arg)
		end

		return
	end

	Recount2:SetWindowTop(self)
	self:StartMoving()
end

local function Window_MouseUp(self)
	self:StopMovingOrSizing()
end

local function Window_SideMove(self)
	Recount2:SetWindowTop(self:GetParent())
	self:GetParent():StartSizing(self.pointSize)
end

local function Window_SideUp(self)
	self:GetParent():StopMovingOrSizing()
end

local ResizeCursors = {
	["TOPLEFT"]	= "Interface\\Addons\\Recount2\\Textures\\Cursors\\cursor_ULDR_resize.blp",
	["TOP"]		= "Interface\\Addons\\Recount2\\Textures\\Cursors\\cursor_UD_resize.blp",
	["TOPRIGHT"]	= "Interface\\Addons\\Recount2\\Textures\\Cursors\\cursor_DLUR_resize.blp",
	["LEFT"]	= "Interface\\Addons\\Recount2\\Textures\\Cursors\\cursor_LR_resize.blp",
	["RIGHT"]	= "Interface\\Addons\\Recount2\\Textures\\Cursors\\cursor_LR_resize.blp",
	["BOTTOMLEFT"]	= "Interface\\Addons\\Recount2\\Textures\\Cursors\\cursor_DLUR_resize.blp",
	["BOTTOM"]	= "Interface\\Addons\\Recount2\\Textures\\Cursors\\cursor_UD_resize.blp",
	["BOTTOMRIGHT"]	= "Interface\\Addons\\Recount2\\Textures\\Cursors\\cursor_ULDR_resize.blp",
}

local function Window_SideEnter(self)
	SetCursor(ResizeCursors[self.pointSize])
end

local function Window_SideLeave(self)
	ResetCursor()
end

local function CreateMoveFrame(parent, anchor)
	local moveFrame = CreateFrame("FRAME", nil, parent)
	moveFrame.pointSize = anchor
	moveFrame.SideMove = Window_SideMove
	moveFrame.MouseUp = Window_SideUp
	moveFrame.OnEnter = Window_SideEnter
	moveFrame.OnLeave = Window_SideLeave
	moveFrame:SetScript("OnMouseDown", moveFrame.SideMove)
	moveFrame:SetScript("OnMouseUp", moveFrame.MouseUp)
	moveFrame:SetScript("OnEnter", moveFrame.OnEnter)
	moveFrame:SetScript("OnLeave", moveFrame.OnLeave)
	moveFrame:EnableMouse()

	return moveFrame
end

local function Window_SetTitle(self, title)
	self.title:SetText(title)
end

local function Window_SetRightClickTitleFunc(self, func, arg)
	self.rightClickTitleFunc = func
	self.arg = arg
end

local function closeParent(self)
	self:GetParent():Hide()
end

local function highlightOn(self)
	self.htexture:Show()
end

local function highlightOff(self)
	self.htexture:Hide()
end

local function Window_MakeUnresizable(self)
	self.topMove:Hide()
	self.topLeft1Move:Hide()	
	self.topLeft2Move:Hide()
	self.topRight1Move:Hide()
	self.topRight2Move:Hide()
	self.leftMove:Hide()
	self.rightMove:Hide()
	self.bottomMove:Hide()
	self.bottomLeft1Move:Hide()
	self.bottomLeft2Move:Hide()
	self.bottomRight1Move:Hide()
	self.bottomRight2Move:Hide()

	self:SetResizable(false)
end

--/script a=Recount2.Widgets:CreateWindow("testWindow", 256, 256);a:SetPoint("CENTER", UIParent, "CENTER")
function Recount2_Widgets:CreateWindow(name, width, height)
	local window = CreateFrame("FRAME", name, UIParent)
	local titleHeight = 18

	local colorTexture = "Interface\\Addons\\Recount2\\Textures\\windowLunaC.tga"
	local highlightTexture = "Interface\\Addons\\Recount2\\Textures\\windowLunaH.tga"
	local closeTexture = "Interface\\Addons\\Recount2\\Textures\\closeButtonLuna.tga"
	local closeHighlightTexture = "Interface\\Addons\\Recount2\\Textures\\closeButtonHighlightLuna.tga"

	titleHeight = titleHeight * 32/28

	window:SetWidth(width)
	window:SetHeight(height)
	
	window.borderTopLeftC = window:CreateTexture(nil, "BORDER")
	window.borderTopLeftC:SetWidth(32)
	window.borderTopLeftC:SetHeight(titleHeight)
	window.borderTopLeftC:SetPoint("TOPLEFT", window, "TOPLEFT")
	window.borderTopLeftC:SetTexture(colorTexture)
	window.borderTopLeftC:SetTexCoord(0.5, 0, 0.5, 1.0, 0.625, 0, 0.625, 1.0)

	window.borderTopLeftH = window:CreateTexture(nil, "ARTWORK")
	window.borderTopLeftH:SetWidth(32)
	window.borderTopLeftH:SetHeight(titleHeight)
	window.borderTopLeftH:SetPoint("TOPLEFT", window, "TOPLEFT")
	window.borderTopLeftH:SetTexture(highlightTexture)
	window.borderTopLeftH:SetTexCoord(0.5, 0, 0.5, 1.0, 0.625, 0, 0.625, 1.0)

	window.borderTopC = window:CreateTexture(nil, "BORDER")
	window.borderTopC:SetHeight(titleHeight)
	window.borderTopC:SetPoint("TOPLEFT", window, "TOPLEFT", 32, 0)
	window.borderTopC:SetPoint("TOPRIGHT", window, "TOPRIGHT", -32, 0)
	window.borderTopC:SetTexture(colorTexture)
	window.borderTopC:SetTexCoord(0.25, 1.0, 0.375, 1.0, 0.25, 0.0, 0.375, 0.0)

	window.borderTopH = window:CreateTexture(nil, "ARTWORK")
	window.borderTopH:SetHeight(titleHeight)
	window.borderTopH:SetPoint("TOPLEFT", window, "TOPLEFT", 32, 0)
	window.borderTopH:SetPoint("TOPRIGHT", window, "TOPRIGHT", -32, 0)
	window.borderTopH:SetTexture(highlightTexture)
	window.borderTopH:SetTexCoord(0.25, 1.0, 0.375, 1.0, 0.25, 0.0, 0.375, 0.0)

	window.borderTopRightC = window:CreateTexture(nil, "BORDER")
	window.borderTopRightC:SetWidth(32)
	window.borderTopRightC:SetHeight(titleHeight)
	window.borderTopRightC:SetPoint("TOPRIGHT", window, "TOPRIGHT")
	window.borderTopRightC:SetTexture(colorTexture)
	window.borderTopRightC:SetTexCoord(0.625, 0.0, 0.625, 1.0, 0.75, 0.0, 0.75, 1.0)

	window.borderTopRightH = window:CreateTexture(nil, "ARTWORK")
	window.borderTopRightH:SetWidth(32)
	window.borderTopRightH:SetHeight(titleHeight)
	window.borderTopRightH:SetPoint("TOPRIGHT", window, "TOPRIGHT")
	window.borderTopRightH:SetTexture(highlightTexture)
	window.borderTopRightH:SetTexCoord(0.625, 0.0, 0.625, 1.0, 0.75, 0.0, 0.75, 1.0)


	window.borderBottomLeftC = window:CreateTexture(nil, "BORDER")
	window.borderBottomLeftC:SetWidth(32)
	window.borderBottomLeftC:SetHeight(32)
	window.borderBottomLeftC:SetPoint("BOTTOMLEFT", window, "BOTTOMLEFT")
	window.borderBottomLeftC:SetTexture(colorTexture)
	window.borderBottomLeftC:SetTexCoord(0.75, 0, 0.75, 1.0, 0.875, 0, 0.875, 1.0)

	window.borderBottomLeftH = window:CreateTexture(nil, "ARTWORK")
	window.borderBottomLeftH:SetWidth(32)
	window.borderBottomLeftH:SetHeight(32)
	window.borderBottomLeftH:SetPoint("BOTTOMLEFT", window, "BOTTOMLEFT")
	window.borderBottomLeftH:SetTexture(highlightTexture)
	window.borderBottomLeftH:SetTexCoord(0.75, 0, 0.75, 1.0, 0.875, 0, 0.875, 1.0)

	window.borderBottomC = window:CreateTexture(nil, "BORDER")
	window.borderBottomC:SetWidth(width-64)
	window.borderBottomC:SetHeight(32)
	window.borderBottomC:SetPoint("BOTTOMLEFT", window, "BOTTOMLEFT", 32, 0)
	window.borderBottomC:SetPoint("BOTTOMRIGHT", window, "BOTTOMRIGHT", -32, 0)
	window.borderBottomC:SetTexture(colorTexture)
	window.borderBottomC:SetTexCoord(0.375, 1.0, 0.5, 1.0, 0.375, 0.0, 0.5, 0.0)

	window.borderBottomH = window:CreateTexture(nil, "ARTWORK")
	window.borderBottomH:SetHeight(32)
	window.borderBottomH:SetPoint("BOTTOMLEFT", window, "BOTTOMLEFT", 32, 0)
	window.borderBottomH:SetPoint("BOTTOMRIGHT", window, "BOTTOMRIGHT", -32, 0)
	window.borderBottomH:SetTexture(highlightTexture)
	window.borderBottomH:SetTexCoord(0.375, 1.0, 0.5, 1.0, 0.375, 0.0, 0.5, 0.0)

	window.borderBottomRightC = window:CreateTexture(nil, "BORDER")
	window.borderBottomRightC:SetWidth(32)
	window.borderBottomRightC:SetHeight(32)
	window.borderBottomRightC:SetPoint("BOTTOMRIGHT", window, "BOTTOMRIGHT")
	window.borderBottomRightC:SetTexture(colorTexture)
	window.borderBottomRightC:SetTexCoord(0.875, 0.0, 0.875, 1.0, 1.0, 0.0, 1.0, 1.0)

	window.borderBottomRightH = window:CreateTexture(nil, "ARTWORK")
	window.borderBottomRightH:SetWidth(32)
	window.borderBottomRightH:SetHeight(32)
	window.borderBottomRightH:SetPoint("BOTTOMRIGHT", window, "BOTTOMRIGHT")
	window.borderBottomRightH:SetTexture(highlightTexture)
	window.borderBottomRightH:SetTexCoord(0.875, 0.0, 0.875, 1.0, 1.0, 0.0, 1.0, 1.0)


	window.borderLeftC = window:CreateTexture(nil, "BORDER")
	window.borderLeftC:SetWidth(32)
	window.borderLeftC:SetPoint("TOPLEFT", window, "TOPLEFT", 0, -titleHeight)
	window.borderLeftC:SetPoint("BOTTOMLEFT", window, "BOTTOMLEFT", 0, 32)
	window.borderLeftC:SetTexture(colorTexture)
	window.borderLeftC:SetTexCoord(0.0, 0.0, 0.0, 1.0, 0.125, 0.0, 0.125, 1.0)

	window.borderLeftH = window:CreateTexture(nil, "ARTWORK")
	window.borderLeftH:SetWidth(32)
	window.borderLeftH:SetPoint("TOPLEFT", window, "TOPLEFT", 0, -titleHeight)
	window.borderLeftH:SetPoint("BOTTOMLEFT", window, "BOTTOMLEFT", 0, 32)
	window.borderLeftH:SetTexture(highlightTexture)
	window.borderLeftH:SetTexCoord(0.0, 0.0, 0.0, 1.0, 0.125, 0.0, 0.125, 1.0)

	window.borderRightC = window:CreateTexture(nil, "BORDER")
	window.borderRightC:SetWidth(32)
	window.borderRightC:SetPoint("TOPRIGHT", window, "TOPRIGHT", 0, -titleHeight)
	window.borderRightC:SetPoint("BOTTOMRIGHT", window, "BOTTOMRIGHT", 0, 32)
	window.borderRightC:SetTexture(colorTexture)
	window.borderRightC:SetTexCoord(0.125, 0.0, 0.125, 1.0, 0.25, 0.0, 0.25, 1.0)

	window.borderRightH = window:CreateTexture(nil, "ARTWORK")
	window.borderRightH:SetWidth(32)
	window.borderRightH:SetPoint("TOPRIGHT", window, "TOPRIGHT", 0, -titleHeight)
	window.borderRightH:SetPoint("BOTTOMRIGHT", window, "BOTTOMRIGHT", 0, 32)
	window.borderRightH:SetTexture(highlightTexture)
	window.borderRightH:SetTexCoord(0.125, 0.0, 0.125, 1.0, 0.25, 0.0, 0.25, 1.0)


	window.background = window:CreateTexture(nil, "BACKGROUND")
	window.background:SetTexture(0.0, 0.0, 0.0, 0.75)
	window.background:SetPoint("BOTTOMLEFT", window, "BOTTOMLEFT", 3, 3)
	window.background:SetPoint("TOPRIGHT", window, "TOPRIGHT", -3, -titleHeight/32*20)
	
	local color = {0.0, 0.0, 0.0, 1.0}
	--local color = {0.25, 0.5, 1.0, 1.0}
	window.borderTopLeftC:SetVertexColor(color[1], color[2], color[3], color[4])
	window.borderTopC:SetVertexColor(color[1], color[2], color[3], color[4])
	window.borderTopRightC:SetVertexColor(color[1], color[2], color[3], color[4])
	window.borderBottomLeftC:SetVertexColor(color[1], color[2], color[3], color[4])
	window.borderBottomC:SetVertexColor(color[1], color[2], color[3], color[4])
	window.borderBottomRightC:SetVertexColor(color[1], color[2], color[3], color[4])
	window.borderLeftC:SetVertexColor(color[1], color[2], color[3], color[4])
	window.borderRightC:SetVertexColor(color[1], color[2], color[3], color[4])

	local highlight = 1.0
	--local highlight = 0.35
	window.borderTopLeftH:SetVertexColor(1.0, 1.0, 1.0, highlight)
	window.borderTopH:SetVertexColor(1.0, 1.0, 1.0, highlight)
	window.borderTopRightH:SetVertexColor(1.0, 1.0, 1.0, highlight)
	window.borderBottomLeftH:SetVertexColor(1.0, 1.0, 1.0, highlight)
	window.borderBottomH:SetVertexColor(1.0, 1.0, 1.0, highlight)
	window.borderBottomRightH:SetVertexColor(1.0, 1.0, 1.0, highlight)
	window.borderLeftH:SetVertexColor(1.0, 1.0, 1.0, highlight)
	window.borderRightH:SetVertexColor(1.0, 1.0, 1.0, highlight)

	window.borderTopLeftH:SetBlendMode("ADD")
	window.borderTopH:SetBlendMode("ADD")
	window.borderTopRightH:SetBlendMode("ADD")
	window.borderBottomLeftH:SetBlendMode("ADD")
	window.borderBottomH:SetBlendMode("ADD")
	window.borderBottomRightH:SetBlendMode("ADD")
	window.borderLeftH:SetBlendMode("ADD")
	window.borderRightH:SetBlendMode("ADD")

	window.innerFrame = CreateFrame("FRAME", nil, window)
	window.innerFrame:SetPoint("TOPLEFT", window, "TOPLEFT", 4, -titleHeight/32*29-1)
	window.innerFrame:SetPoint("BOTTOMRIGHT", window, "BOTTOMRIGHT", -4, 4)


	window.MouseDown = Window_MouseDown
	window.MouseUp = Window_MouseUp

	window:SetScript("OnMouseDown", window.MouseDown)
	window:SetScript("OnMouseUp", window.MouseUp)
	window:EnableMouse()

	window.topMove = CreateMoveFrame(window, "TOP")
	window.topMove:SetHeight(4)
	window.topMove:SetPoint("TOPLEFT", window, "TOPLEFT", 16, 0)
	window.topMove:SetPoint("TOPRIGHT", window, "TOPRIGHT", -16, 0)
	

	window.topLeft1Move = CreateMoveFrame(window, "TOPLEFT")
	window.topLeft1Move:SetHeight(4)
	window.topLeft1Move:SetPoint("TOPLEFT", window, "TOPLEFT", 0, 0)
	window.topLeft1Move:SetPoint("TOPRIGHT", window, "TOPLEFT", 16, 0)

	window.topLeft2Move = CreateMoveFrame(window, "TOPLEFT")
	window.topLeft2Move:SetWidth(4)
	window.topLeft2Move:SetPoint("TOPLEFT", window, "TOPLEFT", 0, 0)
	window.topLeft2Move:SetPoint("BOTTOMLEFT", window, "TOPLEFT", 0, -16)

	window.topRight1Move = CreateMoveFrame(window, "TOPRIGHT")
	window.topRight1Move:SetHeight(4)
	window.topRight1Move:SetPoint("TOPRIGHT", window, "TOPRIGHT", 0, 0)
	window.topRight1Move:SetPoint("TOPLEFT", window, "TOPRIGHT", -16, 0)

	window.topRight2Move = CreateMoveFrame(window, "TOPRIGHT")
	window.topRight2Move:SetWidth(4)
	window.topRight2Move:SetPoint("TOPRIGHT", window, "TOPRIGHT", 0, 0)
	window.topRight2Move:SetPoint("BOTTOMRIGHT", window, "TOPRIGHT", 0, -16)

	window.bottomMove = CreateMoveFrame(window, "BOTTOM")
	window.bottomMove:SetHeight(4)
	window.bottomMove:SetPoint("BOTTOMLEFT", window, "BOTTOMLEFT", 16, 0)
	window.bottomMove:SetPoint("BOTTOMRIGHT", window, "BOTTOMRIGHT", -16, 0)

	window.bottomLeft1Move = CreateMoveFrame(window, "BOTTOMLEFT")
	window.bottomLeft1Move:SetHeight(4)
	window.bottomLeft1Move:SetPoint("BOTTOMLEFT", window, "BOTTOMLEFT", 0, 0)
	window.bottomLeft1Move:SetPoint("BOTTOMRIGHT", window, "BOTTOMLEFT", 16, 0)

	window.bottomLeft2Move = CreateMoveFrame(window, "BOTTOMLEFT")
	window.bottomLeft2Move:SetWidth(4)
	window.bottomLeft2Move:SetPoint("BOTTOMLEFT", window, "BOTTOMLEFT", 0, 0)
	window.bottomLeft2Move:SetPoint("TOPLEFT", window, "BOTTOMLEFT", 0, 16)

	window.bottomRight1Move = CreateMoveFrame(window, "BOTTOMRIGHT")
	window.bottomRight1Move:SetHeight(4)
	window.bottomRight1Move:SetPoint("BOTTOMRIGHT", window, "BOTTOMRIGHT", 0, 0)
	window.bottomRight1Move:SetPoint("BOTTOMLEFT", window, "BOTTOMRIGHT", -16, 0)

	window.bottomRight2Move = CreateMoveFrame(window, "BOTTOMRIGHT")
	window.bottomRight2Move:SetWidth(4)
	window.bottomRight2Move:SetPoint("BOTTOMRIGHT", window, "BOTTOMRIGHT", 0, 0)
	window.bottomRight2Move:SetPoint("TOPRIGHT", window, "BOTTOMRIGHT", 0, 16)

	window.leftMove = CreateMoveFrame(window, "LEFT")
	window.leftMove:SetWidth(4)
	window.leftMove:SetPoint("TOPLEFT", window, "TOPLEFT", 0, -16)
	window.leftMove:SetPoint("BOTTOMLEFT", window, "BOTTOMLEFT", 0, 16)

	window.rightMove = CreateMoveFrame(window, "RIGHT")
	window.rightMove:SetWidth(4)
	window.rightMove:SetPoint("TOPRIGHT", window, "TOPRIGHT", 0, -16)
	window.rightMove:SetPoint("BOTTOMRIGHT", window, "BOTTOMRIGHT", 0, 16)

	window:SetMovable(true)
	window:SetResizable(true)
	window:SetMinResize(64, 64)

	window.title = window:CreateFontString(nil,"OVERLAY","GameFontHighlightSmall")
	window.title:SetPoint("TOPLEFT", window, "TOPLEFT", 6, -6*titleHeight/32)
	window.title:SetText("")
	window.title:SetTextColor(1,1,1,1)
	Recount2:AddFontString(window.title)
	SetFontSize(window.title, 20*titleHeight/32)


	window.closeButton = CreateFrame("FRAME", nil, window)
	window.closeButton:SetScript("OnMouseDown", closeParent)
	window.closeButton:SetScript("OnEnter", highlightOn)
	window.closeButton:SetScript("OnLeave", highlightOff)
	window.closeButton:EnableMouse()
	window.closeButton:SetWidth(titleHeight/32*30)
	window.closeButton:SetHeight(titleHeight/32*24)
	window.closeButton:SetPoint("TOPRIGHT", window, "TOPRIGHT", -6, -4)
	

	window.closeButton.texture = window.closeButton:CreateTexture("BACKGROUND", nil)
	window.closeButton.texture:SetTexture(closeTexture)
	window.closeButton.texture:SetWidth(titleHeight)
	window.closeButton.texture:SetHeight(titleHeight)
	window.closeButton.texture:SetPoint("CENTER", window.closeButton, "CENTER")

	window.closeButton.htexture = window.closeButton:CreateTexture("OVERLAY", nil)
	window.closeButton.htexture:SetTexture(closeHighlightTexture)
	window.closeButton.htexture:SetWidth(titleHeight)
	window.closeButton.htexture:SetHeight(titleHeight)
	window.closeButton.htexture:SetPoint("CENTER", window.closeButton, "CENTER")
	window.closeButton.htexture:SetBlendMode("ADD")
	window.closeButton.htexture:SetVertexColor(1, 1, 1, 0.25)
	window.closeButton.htexture:Hide()

	--Want the title clipping on the button
	window.title:SetJustifyH("LEFT")
	window.title:SetPoint("TOPRIGHT", window.closeButton, "TOPLEFT")


	window.SetTitle = Window_SetTitle
	window.SetRightClickTitleFunc = Window_SetRightClickTitleFunc
	window.MakeUnresizable = Window_MakeUnresizable

	window.titleHeight = titleHeight/32*29

	Recount2:AddWindow(window)
	return window
end